import loguru
import sys

logger = loguru.logger


def setup_logger(log_path="logs/"):
    config = {
        "handlers": [
            {
                "sink": log_path + "_{time:YYYY-MM-DD}.log",
                "rotation": "5 MB",
                "retention": "3 days",
                "format": "{time:YYYY-MM-DD HH:mm:ss} - {level} - {file}:{line} - {message}",
                "level": "INFO",
            },
            {
                "sink": sys.stdout,  # <-- Change here
                "level": "INFO",
            },
        ]
    }

    logger.configure(**config)



from distutils.core import setup

setup(
    name='xlogger-lob',  # 对外模块的名字
    version='0.0.2',  # 版本号
    description='',  # 描述
    author='lobsterb',  # 作者
    author_email='57263573@qq.com',
    py_modules=['logger'],  # 要发布的模块
)
